@@ -328,14 +328,6 @@ class AppSettings(object):
     def STAFF_USER_GROUPS(self):
         return self._setting('STAFF_USER_GROUPS', ['staff'], list)
 
-    @property
-    def TEST_USER_USERNAME(self):
-        return self._setting('TEST_USER_USERNAME', 'user')
-
-    @property
-    def TEST_USER_EMAIL(self):
-        return self._setting('TEST_USER_EMAIL', 'user@example.com')
-
     @property
     def LOGOUT_DELETES_ALL_PROFILE_DEVICES(self):
         return self._setting('LOGOUT_DELETES_ALL_PROFILE_DEVICES', False, bool)
