@@ -13,5 +13,5 @@ class Group(DjangoGroup):
         app_label = 'django_sso_app'
         verbose_name = _('Group')
 
-    def get_absolute_url(self):
-        return reverse("django_sso_app_group:detail", args=[self.pk])
+    def get_absolute_rest_url(self):
+        return reverse("django_sso_app_group:rest-detail", args=[self.pk])
