@@ -5,7 +5,6 @@ import logging
 
 from django.contrib.auth import get_user_model
 
-from ...utils import is_test_user
 from ...permissions import is_django_staff
 from ... import app_settings
 
@@ -53,15 +52,9 @@ def get_or_create_user_profile(user, ProfileModel, initials=None, commit=True):
                 profile.sso_rev = 0
 
                 setattr(user, '__dssoa__creating', True)
-                
+
                 profile.save()
 
-        # test user
-        if is_test_user(user):
-            logger.info('User "{}" is TEST_USER, setting sso_id="{}"'.format(user, app_settings.TEST_USER_USERNAME))
-
-            profile.sso_id = app_settings.TEST_USER_USERNAME
-
         profile_initials = initials or getattr(user, '__dssoa__profile__object', None)
 
         if profile_initials is not None:
