@@ -141,7 +141,7 @@ class ProfileApiViewSet(viewsets.ModelViewSet):
     lookup_field = 'sso_id'
     permission_classes = (permissions.IsAuthenticated, )
     filter_backends = (DjangoFilterBackend,)
-    filter_class = ProfileFilter
+    filterset_class = ProfileFilter
     serializer_class = ProfileSerializer
 
     def get_queryset(self):
