@@ -34,7 +34,7 @@ class DjangoSsoAppAppBaseAuthenticationBackend(ModelBackend):
             backend_user = fetch_remote_user(sso_id=sso_id, encoded_jwt=encoded_jwt)
             backend_user_profile = backend_user['profile']
 
-            if backend_user_profile.get('is_incomplete', None) is not None:
+            if backend_user_profile.get('is_incomplete', False):
                 self.redirect_to_profile_complete(request.user)
 
             user = create_local_user_from_remote_backend(backend_user)
