@@ -13,7 +13,6 @@ from .apps.emails.models import EmailAddress
 from .apps.services.models import Service
 from .apps.groups.models import Group
 
-from .utils import is_test_user
 from . import app_settings
 
 logger = logging.getLogger('django_sso_app.core')
@@ -90,36 +89,6 @@ class BaseSignupForm(allauth_SignupForm):
         user_model = get_user_model()
 
         try:
-            if test_mode is None and username == app_settings.TEST_USER_USERNAME:
-                username_field = allauth_app_settings.USER_MODEL_USERNAME_FIELD
-
-                self.add_error(allauth_app_settings.USER_MODEL_USERNAME_FIELD, adapter.error_messages['username_taken'])
-
-                raise forms.ValidationError(
-                    adapter.error_messages['username_taken'],
-                    params={
-                        'model_name': user_model.__name__,
-                        'field_label': username_field,
-                    }
-                )
-
-            if test_mode is None and email == app_settings.TEST_USER_EMAIL:
-                self.add_error('email', adapter.error_messages['email_taken'])
-
-                raise forms.ValidationError(
-                    adapter.error_messages['email_taken'],
-                    params={
-                        'model_name': user_model.__name__,
-                        'field_label': 'email',
-                    }
-                )
-
-            if test_mode is not None and is_test_user(new_user):
-                logger.info('User "{}" is TEST_USER, confirming email "{}"'.format(app_settings.TEST_USER_USERNAME,
-                                                                                   app_settings.TEST_USER_EMAIL))
-
-                adapter.confirm_email(request, EmailAddress.objects.get(email=new_user.email))
-
             if new_user is not None:
                 # service subscription by "referer" field
                 if referer not in [app_settings.APP_URL, '', None]:
