@@ -161,4 +161,4 @@ def renew_response_jwt(received_jwt, user, request, response):
     # expires = datetime.datetime.strftime(datetime.datetime.utcnow() + \
     #     datetime.timedelta(seconds=max_age), "%a, %d-%b-%Y %H:%M:%S GMT")
 
-    set_cookie(response, app_settings.JWT_COOKIE_NAME, token, None)
+    set_cookie(response, app_settings.JWT_COOKIE_NAME, token)
