@@ -4,11 +4,13 @@ import cherrypy
 
 from django_sso_app.config.wsgi import application
 
+SOCKET_FILE = '/tmp/app.sock'
+CHERRYPY_THREAD_POOL_SIZE = os.environ.get('CHERRYPY_THREAD_POOL_SIZE', 30)
+CHERRYPY_SOCKET_HOST = os.environ.get('CHERRYPY_SOCKET_HOST', '0.0.0.0')
+CHERRYPY_SOCKET_PORT = os.environ.get('CHERRYPY_SOCKET_PORT', 5000)
 
-def run(host="0.0.0.0", port=5000):
-    # django settings
-    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'django_sso_app.config.settings.local')
 
+def run(host=CHERRYPY_SOCKET_HOST, port=CHERRYPY_SOCKET_PORT):
     # Mount the application
     cherrypy.tree.graft(application, "/")
 
@@ -21,7 +23,11 @@ def run(host="0.0.0.0", port=5000):
     # Configure the server object
     server.socket_host = host
     server.socket_port = port
-    server.thread_pool = 30
+    server.thread_pool = CHERRYPY_THREAD_POOL_SIZE
+
+    # If in same node use socket files
+    # https://lists.freebsd.org/pipermail/freebsd-performance/2005-February/001143.html
+    server.socket_file = SOCKET_FILE
 
     # For SSL Support
     # server.ssl_module            = 'pyopenssl'
@@ -45,6 +51,10 @@ def run(host="0.0.0.0", port=5000):
     # Start the server engine (Option 1 *and* 2)
 
     cherrypy.engine.start()
+
+    # change socket permissions
+    os.chmod(SOCKET_FILE, 0o777)
+
     cherrypy.engine.block()
 
 
